kalabash-amavis
===============

The `amavis <http://www.amavis.org/>`_ frontend of Kalabash.

Installation
------------

Install this extension system-wide or inside a virtual environment by
running the following command::

  $ pip install kalabash-amavis
